@@ -15,7 +15,7 @@ package API::GitForge::GitLab;
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-$API::GitForge::GitLab::VERSION = '0.002';
+$API::GitForge::GitLab::VERSION = '0.003';
 
 use 5.028;
 use strict;
@@ -107,13 +107,9 @@ sub _clean_config_fork {
 sub _ensure_repo {
     my ($self, $target) = @_;
     my ($ns,   $repo)   = _extract_project_id($target);
-
-    # first we are required to get the namespace id
+    return if $self->{_api}->project($target);
     my $namespace = $self->{_api}->namespace($ns)
       or croak "invalid project namespace $ns";
-
-    # now create the project unless it already exists
-    return if $self->{_api}->project($target);
     $self->{_api}
       ->create_project({ name => $repo, namespace_id => $namespace->{id} });
 }
@@ -126,6 +122,14 @@ sub _nuke_fork {
     $self->{_api}->delete_project("$user/$repo");
 }
 
+sub _ensure_fork_branch_unprotected {
+    my ($self, $upstream, $branch) = @_;
+    my (undef, $repo) = _extract_project_id($upstream);
+    my $user = $self->{_api}->current_user->{username};
+    return unless $self->{_api}->protected_branch("$user/$repo", $branch);
+    $self->{_api}->unprotect_branch("$user/$repo", $branch);
+}
+
 sub _extract_project_id {
     my $project = shift;
     $project =~ s#(?:\.git)?/?$##;
@@ -147,7 +151,7 @@ API::GitForge::GitLab - common git forge operations using the GitLab API
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
